==> nuttx-nuttx-7.14.tar.gz: nuttx-nuttx-7.14/libc/math/lib_atan2f.c <==
/****************************************************************************
 * libc/math/lib_atan2f.c
 *
 * This file is a part of NuttX:
 *
 *   Copyright (C) 2012 Gregory Nutt. All rights reserved.
 *   Ported by: Darcy Gong
 *
 * It derives from the Rhombs OS math library by Nick Johnson which has
 * a compatibile, MIT-style license:
 *
 * Copyright (C) 2009-2011 Nick Johnson <nickbjohnson4224 at gmail.com>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <math.h>

/****************************************************************************
 * Public Functions
 ****************************************************************************/

float atan2f(float y, float x)
{
  if (x > 0)
    {
      return atanf(y / x);
    }
  else if (y >= 0 && x < 0)
    {
      return atanf(y / x) + M_PI;
    }
  else if (y < 0)
    {
      if (x == 0)
        {
          return -M_PI_2;
        }
      else /* Can only be x < 0 */
        {
          return atanf(y / x) - M_PI;
        }
    }
  else if (y > 0 && x == 0)
    {
      return M_PI_2;
    }
  else /* if (y == 0 && x == 0) Undefined but returns normally 0 */
    {
      return 0;
    }
}

==> nuttx-nuttx-7.17.tar.gz: nuttx-nuttx-7.17/libc/math/lib_atan2f.c <==
/****************************************************************************
 * libc/math/lib_atan2f.c
 *
 * This file is a part of NuttX:
 *
 *   Copyright (C) 2012 Gregory Nutt. All rights reserved.
 *   Ported by: Darcy Gong
 *
 * It derives from the Rhombs OS math library by Nick Johnson which has
 * a compatibile, MIT-style license:
 *
 * Copyright (C) 2009-2011 Nick Johnson <nickbjohnson4224 at gmail.com>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <math.h>

/****************************************************************************
 * Public Functions
 ****************************************************************************/

float atan2f(float y, float x)
{
  if (x > 0)
    {
      return atanf(y / x);
    }
  else if (y >= 0 && x < 0)
    {
      return atanf(y / x) + M_PI_F;
    }
  else if (y < 0)
    {
      if (x == 0)
        {
          return -M_PI_2_F;
        }
      else /* Can only be x < 0 */
        {
          return atanf(y / x) - M_PI_F;
        }
    }
  else if (y > 0 && x == 0)
    {
      return M_PI_2_F;
    }
  else /* if (y == 0 && x == 0) Undefined but returns normally 0 */
    {
      return 0;
    }
}
